Core types and data structures for Sigstore
This crate provides the fundamental data structures used throughout the Sigstore ecosystem, including bundle formats, transparency log entries, and trust roots.
Re-exports
pub use artifact::Artifact;pub use bundle::Bundle;pub use bundle::BundleVersion;pub use bundle::CheckpointData;pub use bundle::InclusionPromise;pub use bundle::InclusionProof;pub use bundle::KindVersion;pub use bundle::LogId;pub use bundle::MediaType;pub use bundle::MessageDigest;pub use bundle::MessageSignature;pub use bundle::SignatureContent;pub use bundle::TransparencyLogEntry;pub use bundle::VerificationMaterial;pub use checkpoint::Checkpoint;pub use checkpoint::CheckpointSignature;pub use dsse::pae;pub use dsse::DsseEnvelope;pub use dsse::DsseSignature;pub use encoding::base64_bytes;pub use encoding::base64_bytes_option;pub use encoding::hex_bytes;pub use encoding::string_i64;pub use encoding::CanonicalizedBody;pub use encoding::DerCertificate;pub use encoding::DerPublicKey;pub use encoding::EntryUuid;pub use encoding::HexHash;pub use encoding::HexLogId;pub use encoding::KeyHint;pub use encoding::KeyId;pub use encoding::LogIndex;pub use encoding::LogKeyId;pub use encoding::PayloadBytes;pub use encoding::PemContent;pub use encoding::Sha256Hash;pub use encoding::SignatureBytes;pub use encoding::SignedTimestamp;pub use encoding::TimestampToken;pub use error::Error;pub use error::Result;pub use hash::HashAlgorithm;pub use intoto::Digest;pub use intoto::Statement;pub use intoto::Subject;
Modules
- artifact
- Artifact types for signing and verification
- bundle
- Sigstore bundle format types
- checkpoint
- Checkpoint (signed tree head) types
- dsse
- Dead Simple Signing Envelope (DSSE) types
- encoding
- Encoding helpers and concrete types for sigstore
- error
- Error types for sigstore-types
- hash
- Hash algorithm types and utilities
- intoto
- In-toto attestation types